@@ -38,6 +38,9 @@ describe 'nova::compute::rbd' do
         is_expected.to contain_nova_config('libvirt/images_rbd_glance_store_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('libvirt/images_rbd_glance_copy_poll_interval').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('libvirt/images_rbd_glance_copy_timeout').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('libvirt/rbd_connect_timeout').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('libvirt/rbd_destroy_volume_retry_interval').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('libvirt/rbd_destroy_volume_retries').with_value('<SERVICE DEFAULT>')
     end
 
     it 'installs client package' do
@@ -52,112 +55,70 @@ describe 'nova::compute::rbd' do
       before :each do
         params.merge!(
           :libvirt_rbd_user                             => 'joe',
-          :libvirt_rbd_secret_uuid                      => false,
           :libvirt_images_rbd_pool                      => 'AnotherPool',
           :libvirt_images_rbd_ceph_conf                 => '/tmp/ceph.conf',
           :libvirt_images_rbd_glance_store_name         => 'glance_rbd_store',
           :libvirt_images_rbd_glance_copy_poll_interval => 30,
-          :libvirt_images_rbd_glance_copy_timeout       => 300
+          :libvirt_images_rbd_glance_copy_timeout       => 300,
+          :libvirt_rbd_connect_timeout                  => 5,
+          :libvirt_rbd_destroy_volume_retry_interval    => 5,
+          :libvirt_rbd_destroy_volume_retries           => 12,
         )
       end
 
       it 'configure nova.conf with overridden parameters' do
-          is_expected.to contain_nova_config('libvirt/images_rbd_pool').with_value('AnotherPool')
-          is_expected.to contain_nova_config('libvirt/images_rbd_ceph_conf').with_value('/tmp/ceph.conf')
-          is_expected.to contain_nova_config('libvirt/rbd_user').with_value('joe')
-          is_expected.to contain_nova_config('libvirt/images_rbd_glance_store_name').with_value('glance_rbd_store')
-          is_expected.to contain_nova_config('libvirt/images_rbd_glance_copy_poll_interval').with_value(30)
-          is_expected.to contain_nova_config('libvirt/images_rbd_glance_copy_timeout').with_value(300)
+        is_expected.to contain_nova_config('libvirt/images_rbd_pool').with_value('AnotherPool')
+        is_expected.to contain_nova_config('libvirt/images_rbd_ceph_conf').with_value('/tmp/ceph.conf')
+        is_expected.to contain_nova_config('libvirt/rbd_user').with_value('joe')
+        is_expected.to contain_nova_config('libvirt/images_rbd_glance_store_name').with_value('glance_rbd_store')
+        is_expected.to contain_nova_config('libvirt/images_rbd_glance_copy_poll_interval').with_value(30)
+        is_expected.to contain_nova_config('libvirt/images_rbd_glance_copy_timeout').with_value(300)
+        is_expected.to contain_nova_config('libvirt/rbd_connect_timeout').with_value(5)
+        is_expected.to contain_nova_config('libvirt/rbd_destroy_volume_retry_interval').with_value(5)
+        is_expected.to contain_nova_config('libvirt/rbd_destroy_volume_retries').with_value(12)
       end
     end
 
     context 'when using cephx' do
-      before :each do
+      before do
         params.merge!(
-          :libvirt_rbd_secret_uuid => 'UUID',
-          :rbd_keyring             => 'client.rbd_test'
+          :libvirt_rbd_secret_uuid => '4f515eff-47e4-425c-b24d-9c6adc56401c',
+          :libvirt_rbd_secret_key  => 'AQBHCbtT6APDHhAA5W00cBchwkQjh3dkKsyPjw==',
         )
       end
 
-      it 'configure nova.conf with RBD secret UUID' do
-          is_expected.to contain_nova_config('libvirt/rbd_secret_uuid').with_value('UUID')
-      end
-
-      it 'configure ceph on compute nodes' do
-        verify_contents(catalogue, '/etc/nova/secret.xml', [
-          "<secret ephemeral=\'no\' private=\'no\'>",
-          "  <usage type=\'ceph\'>",
-          "    <name>client.rbd_test secret</name>",
-          "  </usage>",
-          "  <uuid>UUID</uuid>",
-          "</secret>"
-        ])
-        is_expected.to contain_exec('get-or-set virsh secret').with(
-          :command =>  '/usr/bin/virsh secret-define --file /etc/nova/secret.xml | /usr/bin/awk \'{print $2}\' | sed \'/^$/d\' > /etc/nova/virsh.secret',
-          :unless  => '/usr/bin/virsh secret-list | grep -i UUID',
-          :require => 'File[/etc/nova/secret.xml]',
-        )
-        is_expected.to contain_exec('set-secret-value virsh').with(
-          :command   => "/usr/bin/virsh secret-set-value --secret UUID --base64 $(ceph auth get-key client.rbd_test)",
-          :logoutput => false,
-        )
-      end
-    end
-
-    context 'when using cephx and passing libvirt_rbd_secret_key' do
-      before :each do
-        params.merge!(
-          :libvirt_rbd_secret_uuid => 'UUID',
-          :libvirt_rbd_secret_key  => 'LIBVIRT/SECRET/KEY',
-        )
-      end
-
-      it 'set libvirt secret key from passed key' do
-        is_expected.to contain_exec('set-secret-value virsh').with(
-          :command   => "/usr/bin/virsh secret-set-value --secret #{params[:libvirt_rbd_secret_uuid]} --base64 #{params[:libvirt_rbd_secret_key]}",
-          :logoutput => false,
-        )
-      end
+      it { is_expected.to contain_nova__compute__libvirt__secret_ceph('4f515eff-47e4-425c-b24d-9c6adc56401c').with(
+        :uuid  => '4f515eff-47e4-425c-b24d-9c6adc56401c',
+        :value => 'AQBHCbtT6APDHhAA5W00cBchwkQjh3dkKsyPjw==',
+      )}
     end
 
     context 'when using cephx but disabling ephemeral storage' do
-      before :each do
+      before do
         params.merge!(
-          :libvirt_rbd_secret_uuid      => 'UUID',
-          :rbd_keyring                  => 'client.rbd_test',
-          :ephemeral_storage            => false
+          :libvirt_rbd_secret_uuid => '4f515eff-47e4-425c-b24d-9c6adc56401c',
+          :libvirt_rbd_secret_key  => 'AQBHCbtT6APDHhAA5W00cBchwkQjh3dkKsyPjw==',
+          :ephemeral_storage       => false
         )
       end
 
       it 'should only set user and secret_uuid in nova.conf ' do
-          is_expected.to contain_nova_config('libvirt/images_rbd_pool').with_ensure('absent')
-          is_expected.to contain_nova_config('libvirt/images_rbd_ceph_conf').with_ensure('absent')
-          is_expected.to contain_nova_config('libvirt/images_rbd_glance_store_name').with_ensure('absent')
-          is_expected.to contain_nova_config('libvirt/images_rbd_glance_copy_poll_interval').with_ensure('absent')
-          is_expected.to contain_nova_config('libvirt/images_rbd_glance_copy_timeout').with_ensure('absent')
-          is_expected.to contain_nova_config('libvirt/rbd_user').with_value('nova')
-          is_expected.to contain_nova_config('libvirt/rbd_secret_uuid').with_value('UUID')
+        is_expected.to contain_nova_config('libvirt/images_rbd_pool').with_ensure('absent')
+        is_expected.to contain_nova_config('libvirt/images_rbd_ceph_conf').with_ensure('absent')
+        is_expected.to contain_nova_config('libvirt/images_rbd_glance_store_name').with_ensure('absent')
+        is_expected.to contain_nova_config('libvirt/images_rbd_glance_copy_poll_interval').with_ensure('absent')
+        is_expected.to contain_nova_config('libvirt/images_rbd_glance_copy_timeout').with_ensure('absent')
+        is_expected.to contain_nova_config('libvirt/rbd_connect_timeout').with_ensure('absent')
+        is_expected.to contain_nova_config('libvirt/rbd_destroy_volume_retry_interval').with_ensure('absent')
+        is_expected.to contain_nova_config('libvirt/rbd_destroy_volume_retries').with_ensure('absent')
+        is_expected.to contain_nova_config('libvirt/rbd_user').with_value('nova')
+        is_expected.to contain_nova_config('libvirt/rbd_secret_uuid').with_value('4f515eff-47e4-425c-b24d-9c6adc56401c')
       end
 
-      it 'configure ceph on compute nodes' do
-        verify_contents(catalogue, '/etc/nova/secret.xml', [
-          "<secret ephemeral=\'no\' private=\'no\'>",
-          "  <usage type=\'ceph\'>",
-          "    <name>client.rbd_test secret</name>",
-          "  </usage>",
-          "  <uuid>UUID</uuid>",
-          "</secret>"
-        ])
-        is_expected.to contain_exec('get-or-set virsh secret').with(
-          :command =>  '/usr/bin/virsh secret-define --file /etc/nova/secret.xml | /usr/bin/awk \'{print $2}\' | sed \'/^$/d\' > /etc/nova/virsh.secret',
-          :unless  => '/usr/bin/virsh secret-list | grep -i UUID',
-          :require => 'File[/etc/nova/secret.xml]',
-        )
-        is_expected.to contain_exec('set-secret-value virsh').with(
-          :command   => "/usr/bin/virsh secret-set-value --secret UUID --base64 $(ceph auth get-key client.rbd_test)",
-          :logoutput => false,
-        )
-      end
+      it { is_expected.to contain_nova__compute__libvirt__secret_ceph('4f515eff-47e4-425c-b24d-9c6adc56401c').with(
+        :uuid  => '4f515eff-47e4-425c-b24d-9c6adc56401c',
+        :value => 'AQBHCbtT6APDHhAA5W00cBchwkQjh3dkKsyPjw==',
+      )}
     end
 
     context 'when not managing ceph client' do
