@@ -35,9 +35,10 @@ describe 'nova::compute' do
       end
 
       it { is_expected.to contain_nova_config('DEFAULT/use_cow_images').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_nova_config('DEFAULT/mkisofs_cmd').with_value(platform_params[:mkisofs_cmd]) }
+      it { is_expected.to contain_nova_config('DEFAULT/mkisofs_cmd').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/force_raw_images').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/virt_mkfs').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/reserved_host_cpus').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/reserved_host_memory_mb').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/reserved_host_disk_mb').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/reserved_huge_pages').with_value('<SERVICE DEFAULT>') }
@@ -65,6 +66,10 @@ describe 'nova::compute' do
       it { is_expected.to contain_nova_config('compute/image_type_exclude_list').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/block_device_allocate_retries').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/block_device_allocate_retries_interval').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/instance_usage_audit').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/instance_usage_audit_period').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/flat_injected').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/config_drive_format').with_value('<SERVICE DEFAULT>') }
 
       it { is_expected.to_not contain_package('bridge-utils').with(
         :ensure => 'present',
@@ -72,15 +77,6 @@ describe 'nova::compute' do
 
       it { is_expected.to contain_class('nova::policy') }
       it { is_expected.to contain_class('nova::availability_zone') }
-
-      it 'installs mkisofs package and sets config_drive_format' do
-        is_expected.to contain_nova_config('DEFAULT/config_drive_format').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_package(platform_params[:mkisofs_package]).with(
-          :ensure => 'installed',
-        )
-        is_expected.to contain_package(platform_params[:mkisofs_package]).that_requires('Anchor[nova::install::begin]')
-        is_expected.to contain_package(platform_params[:mkisofs_package]).that_comes_before('Anchor[nova::install::end]')
-      end
     end
 
     context 'with overridden parameters' do
@@ -92,8 +88,9 @@ describe 'nova::compute' do
           :mkisofs_cmd                        => 'mkisofs',
           :force_raw_images                   => false,
           :virt_mkfs                          => 'windows=mkfs.ntfs --force --fast %(target)s',
-          :reserved_host_memory               => '0',
-          :reserved_host_disk                 => '20',
+          :reserved_host_cpus                 => 2,
+          :reserved_host_memory               => 0,
+          :reserved_host_disk                 => 20,
           :heal_instance_info_cache_interval  => '120',
           :config_drive_format                => 'vfat',
           :update_resources_interval          => '300',
@@ -153,8 +150,9 @@ describe 'nova::compute' do
       it { is_expected.to contain_nova_config('DEFAULT/mkisofs_cmd').with_value('mkisofs') }
       it { is_expected.to contain_nova_config('DEFAULT/force_raw_images').with_value(false) }
       it { is_expected.to contain_nova_config('DEFAULT/virt_mkfs').with_value('windows=mkfs.ntfs --force --fast %(target)s') }
-      it { is_expected.to contain_nova_config('DEFAULT/reserved_host_memory_mb').with_value('0') }
-      it { is_expected.to contain_nova_config('DEFAULT/reserved_host_disk_mb').with_value('20') }
+      it { is_expected.to contain_nova_config('DEFAULT/reserved_host_cpus').with_value(2) }
+      it { is_expected.to contain_nova_config('DEFAULT/reserved_host_memory_mb').with_value(0) }
+      it { is_expected.to contain_nova_config('DEFAULT/reserved_host_disk_mb').with_value(20) }
       it { is_expected.to contain_nova_config('DEFAULT/heal_instance_info_cache_interval').with_value('120') }
       it { is_expected.to contain_nova_config('DEFAULT/update_resources_interval').with_value('300') }
       it { is_expected.to contain_nova_config('DEFAULT/reboot_timeout').with_value('180') }
@@ -179,13 +177,7 @@ describe 'nova::compute' do
       it { is_expected.to contain_nova_config('compute/image_type_exclude_list').with_value('raw,ami') }
       it { is_expected.to contain_nova_config('DEFAULT/block_device_allocate_retries').with_value(60) }
       it { is_expected.to contain_nova_config('DEFAULT/block_device_allocate_retries_interval').with_value(3) }
-
-      it 'configures nova config_drive_format to vfat' do
-        is_expected.to contain_nova_config('DEFAULT/config_drive_format').with_value('vfat')
-        is_expected.to_not contain_package(platform_params[:mkisofs_package]).with(
-          :ensure => 'present',
-        )
-      end
+      it { is_expected.to contain_nova_config('DEFAULT/config_drive_format').with_value('vfat') }
     end
 
     context 'with image_type_exclude_list set to empty list' do
@@ -299,14 +291,6 @@ describe 'nova::compute' do
       it { should raise_error(Puppet::Error, /vnc_enabled and spice_enabled is mutually exclusive/) }
     end
 
-    context 'with force_config_drive parameter set to true' do
-      let :params do
-        { :force_config_drive => true }
-      end
-
-      it { is_expected.to contain_nova_config('DEFAULT/force_config_drive').with_value(true) }
-    end
-
     context 'while not managing service state' do
       let :params do
         {
@@ -317,15 +301,6 @@ describe 'nova::compute' do
       it { is_expected.to_not contain_service('nova-compute') }
     end
 
-    context 'with instance_usage_audit parameter set to false' do
-      let :params do
-        { :instance_usage_audit => false, }
-      end
-
-      it { is_expected.to contain_nova_config('DEFAULT/instance_usage_audit').with_ensure('absent') }
-      it { is_expected.to contain_nova_config('DEFAULT/instance_usage_audit_period').with_ensure('absent') }
-    end
-
     context 'with instance_usage_audit parameter and period' do
       let :params do
         { :instance_usage_audit        => true,
@@ -336,6 +311,21 @@ describe 'nova::compute' do
       it { is_expected.to contain_nova_config('DEFAULT/instance_usage_audit_period').with_value('year') }
     end
 
+    context 'with flat_injected parameter set to true' do
+      let :params do
+        { :flat_injected => true }
+      end
+
+      it { is_expected.to contain_nova_config('DEFAULT/flat_injected').with_value(true) }
+    end
+
+    context 'with force_config_drive parameter set to true' do
+      let :params do
+        { :force_config_drive => true }
+      end
+
+      it { is_expected.to contain_nova_config('DEFAULT/force_config_drive').with_value(true) }
+    end
   end
 
   on_supported_os({
@@ -351,8 +341,6 @@ describe 'nova::compute' do
           {
             :nova_compute_package => 'nova-compute',
             :nova_compute_service => 'nova-compute',
-            :mkisofs_package      => 'genisoimage',
-            :mkisofs_cmd          => '<SERVICE DEFAULT>'
           }
         end
       when 'RedHat'
@@ -360,8 +348,6 @@ describe 'nova::compute' do
           {
             :nova_compute_package => 'openstack-nova-compute',
             :nova_compute_service => 'openstack-nova-compute',
-            :mkisofs_package      => 'xorriso',
-            :mkisofs_cmd          => 'mkisofs'
           }
         end
       end
