@@ -41,6 +41,7 @@ describe 'nova' do
           :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
           :heartbeat_rate                  => '<SERVICE DEFAULT>',
           :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
+          :rabbit_qos_prefetch_count       => '<SERVICE DEFAULT>',
           :kombu_reconnect_delay           => '<SERVICE DEFAULT>',
           :kombu_failover_strategy         => '<SERVICE DEFAULT>',
           :amqp_durable_queues             => '<SERVICE DEFAULT>',
@@ -55,28 +56,14 @@ describe 'nova' do
           :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
+          :enable_cancel_on_failover       => '<SERVICE DEFAULT>',
           :rabbit_retry_interval           => '<SERVICE DEFAULT>',
         )
-        is_expected.to contain_oslo__messaging__amqp('nova_config').with(
-          :server_request_prefix => '<SERVICE DEFAULT>',
-          :broadcast_prefix      => '<SERVICE DEFAULT>',
-          :group_request_prefix  => '<SERVICE DEFAULT>',
-          :container_name        => '<SERVICE DEFAULT>',
-          :idle_timeout          => '<SERVICE DEFAULT>',
-          :trace                 => '<SERVICE DEFAULT>',
-          :ssl_ca_file           => '<SERVICE DEFAULT>',
-          :ssl_cert_file         => '<SERVICE DEFAULT>',
-          :ssl_key_file          => '<SERVICE DEFAULT>',
-          :sasl_mechanisms       => '<SERVICE DEFAULT>',
-          :sasl_config_dir       => '<SERVICE DEFAULT>',
-          :sasl_config_name      => '<SERVICE DEFAULT>',
-          :username              => '<SERVICE DEFAULT>',
-          :password              => '<SERVICE DEFAULT>',
-        )
         is_expected.to contain_oslo__messaging__notifications('nova_config').with(
           :transport_url => '<SERVICE DEFAULT>',
           :driver        => '<SERVICE DEFAULT>',
           :topics        => '<SERVICE DEFAULT>',
+          :retry         => '<SERVICE DEFAULT>',
         )
       end
 
@@ -114,61 +101,57 @@ describe 'nova' do
 
       let :params do
         {
-          :default_transport_url                   => 'rabbit://rabbit_user:password@localhost:5673',
-          :rpc_response_timeout                    => '30',
-          :long_rpc_timeout                        => '1800',
-          :control_exchange                        => 'nova',
-          :executor_thread_pool_size               => 64,
-          :rabbit_use_ssl                          => true,
-          :rabbit_heartbeat_timeout_threshold      => '60',
-          :rabbit_heartbeat_rate                   => '10',
-          :rabbit_heartbeat_in_pthread             => true,
-          :kombu_reconnect_delay                   => '5.0',
-          :amqp_durable_queues                     => true,
-          :kombu_compression                       => 'gzip',
-          :kombu_ssl_ca_certs                      => '/etc/ca.cert',
-          :kombu_ssl_certfile                      => '/etc/certfile',
-          :kombu_ssl_keyfile                       => '/etc/key',
-          :kombu_ssl_version                       => 'TLSv1',
-          :rabbit_ha_queues                        => true,
-          :rabbit_quorum_queue                     => true,
-          :rabbit_transient_quorum_queue           => true,
-          :rabbit_quorum_delivery_limit            => 3,
-          :rabbit_quorum_max_memory_length         => 5,
-          :rabbit_quorum_max_memory_bytes          => 1073741824,
-          :rabbit_retry_interval                   => '1',
-          :amqp_idle_timeout                       => '60',
-          :amqp_trace                              => true,
-          :amqp_ssl_ca_file                        => '/etc/ca.cert',
-          :amqp_ssl_cert_file                      => '/etc/certfile',
-          :amqp_ssl_key_file                       => '/etc/key',
-          :amqp_username                           => 'amqp_user',
-          :amqp_password                           => 'password',
-          :lock_path                               => '/var/locky/path',
-          :state_path                              => '/var/lib/nova2',
-          :service_down_time                       => '60',
-          :auth_strategy                           => 'foo',
-          :ensure_package                          => '2012.1.1-15.el6',
-          :host                                    => 'test-001.example.org',
-          :notification_transport_url              => 'rabbit://rabbit_user:password@localhost:5673',
-          :notification_driver                     => 'ceilometer.compute.nova_notifier',
-          :notification_topics                     => 'openstack',
-          :notification_format                     => 'unversioned',
-          :report_interval                         => '10',
-          :periodic_fuzzy_delay                    => '61',
-          :ovsdb_connection                        => 'tcp:127.0.0.1:6640',
-          :upgrade_level_compute                   => '1.0.0',
-          :upgrade_level_conductor                 => '1.0.0',
-          :upgrade_level_scheduler                 => '1.0.0',
-          :purge_config                            => false,
-          :my_ip                                   => '192.0.2.1',
-          :ssl_only                                => true,
-          :cert                                    => '/etc/ssl/private/snakeoil.pem',
-          :key                                     => '/etc/ssl/certs/snakeoil.pem',
-          :console_ssl_ciphers                     => 'kEECDH+aECDSA+AES:kEECDH+AES+aRSA:kEDH+aRSA+AES',
-          :console_ssl_minimum_version             => 'tlsv1_2',
-          :dhcp_domain                             => 'foo',
-          :instance_name_template                  => 'instance-%08x',
+          :default_transport_url              => 'rabbit://rabbit_user:password@localhost:5673',
+          :rpc_response_timeout               => '30',
+          :long_rpc_timeout                   => '1800',
+          :control_exchange                   => 'nova',
+          :executor_thread_pool_size          => 64,
+          :rabbit_use_ssl                     => true,
+          :rabbit_heartbeat_timeout_threshold => '60',
+          :rabbit_heartbeat_rate              => '10',
+          :rabbit_heartbeat_in_pthread        => true,
+          :rabbit_qos_prefetch_count          => 0,
+          :kombu_reconnect_delay              => '5.0',
+          :amqp_durable_queues                => true,
+          :kombu_compression                  => 'gzip',
+          :kombu_ssl_ca_certs                 => '/etc/ca.cert',
+          :kombu_ssl_certfile                 => '/etc/certfile',
+          :kombu_ssl_keyfile                  => '/etc/key',
+          :kombu_ssl_version                  => 'TLSv1',
+          :rabbit_ha_queues                   => true,
+          :rabbit_quorum_queue                => true,
+          :rabbit_transient_quorum_queue      => true,
+          :rabbit_quorum_delivery_limit       => 3,
+          :rabbit_quorum_max_memory_length    => 5,
+          :rabbit_quorum_max_memory_bytes     => 1073741824,
+          :rabbit_enable_cancel_on_failover   => false,
+          :rabbit_retry_interval              => '1',
+          :lock_path                          => '/var/locky/path',
+          :state_path                         => '/var/lib/nova2',
+          :service_down_time                  => '60',
+          :auth_strategy                      => 'foo',
+          :ensure_package                     => '2012.1.1-15.el6',
+          :host                               => 'test-001.example.org',
+          :notification_transport_url         => 'rabbit://rabbit_user:password@localhost:5673',
+          :notification_driver                => 'ceilometer.compute.nova_notifier',
+          :notification_topics                => 'openstack',
+          :notification_retry                 => 10,
+          :notification_format                => 'unversioned',
+          :report_interval                    => '10',
+          :periodic_fuzzy_delay               => '61',
+          :ovsdb_connection                   => 'tcp:127.0.0.1:6640',
+          :upgrade_level_compute              => '1.0.0',
+          :upgrade_level_conductor            => '1.0.0',
+          :upgrade_level_scheduler            => '1.0.0',
+          :purge_config                       => false,
+          :my_ip                              => '192.0.2.1',
+          :ssl_only                           => true,
+          :cert                               => '/etc/ssl/private/snakeoil.pem',
+          :key                                => '/etc/ssl/certs/snakeoil.pem',
+          :console_ssl_ciphers                => 'kEECDH+aECDSA+AES:kEECDH+AES+aRSA:kEDH+aRSA+AES',
+          :console_ssl_minimum_version        => 'tlsv1_2',
+          :dhcp_domain                        => 'foo',
+          :instance_name_template             => 'instance-%08x',
         }
       end
 
@@ -202,6 +185,7 @@ describe 'nova' do
           :heartbeat_timeout_threshold     => '60',
           :heartbeat_rate                  => '10',
           :heartbeat_in_pthread            => true,
+          :rabbit_qos_prefetch_count       => 0,
           :kombu_reconnect_delay           => '5.0',
           :amqp_durable_queues             => true,
           :kombu_compression               => 'gzip',
@@ -215,21 +199,14 @@ describe 'nova' do
           :rabbit_quorum_delivery_limit    => 3,
           :rabbit_quorum_max_memory_length => 5,
           :rabbit_quorum_max_memory_bytes  => 1073741824,
+          :enable_cancel_on_failover       => false,
           :rabbit_retry_interval           => '1',
         )
-        is_expected.to contain_oslo__messaging__amqp('nova_config').with(
-          :idle_timeout  => '60',
-          :trace         => true,
-          :ssl_ca_file   => '/etc/ca.cert',
-          :ssl_cert_file => '/etc/certfile',
-          :ssl_key_file  => '/etc/key',
-          :username      => 'amqp_user',
-          :password      => 'password',
-        )
         is_expected.to contain_oslo__messaging__notifications('nova_config').with(
           :transport_url => 'rabbit://rabbit_user:password@localhost:5673',
           :driver        => 'ceilometer.compute.nova_notifier',
           :topics        => 'openstack',
+          :retry         => 10,
         )
       end
 
@@ -245,9 +222,6 @@ describe 'nova' do
         is_expected.to contain_nova_config('upgrade_levels/compute').with_value('1.0.0')
         is_expected.to contain_nova_config('upgrade_levels/conductor').with_value('1.0.0')
         is_expected.to contain_nova_config('upgrade_levels/scheduler').with_value('1.0.0')
-
-        is_expected.to contain_nova_config('upgrade_levels/cells').with_ensure('absent')
-        is_expected.to contain_nova_config('upgrade_levels/intercell').with_ensure('absent')
       end
 
       it 'configures various things' do
@@ -271,7 +245,12 @@ describe 'nova' do
       end
 
       context 'with multiple notification_driver' do
-        before { params.merge!( :notification_driver => ['ceilometer.compute.nova_notifier', 'nova.openstack.common.notifier.rpc_notifier']) }
+        before do
+          params.merge!( :notification_driver => [
+            'ceilometer.compute.nova_notifier',
+            'nova.openstack.common.notifier.rpc_notifier'
+          ])
+        end
 
         it { is_expected.to contain_oslo__messaging__notifications('nova_config').with(
           :driver => ['ceilometer.compute.nova_notifier', 'nova.openstack.common.notifier.rpc_notifier'],
@@ -306,40 +285,6 @@ describe 'nova' do
       end
     end
 
-    context 'with ssh public key missing key type' do
-      let :params do
-        {
-          :nova_public_key => {'key'  => 'keydata'}
-        }
-      end
-
-      it 'should raise an error' do
-        expect {
-          is_expected.to contain_ssh_authorized_key('nova-migration-public-key').with(
-            :ensure => 'present',
-            :key => 'keydata'
-          )
-        }.to raise_error Puppet::Error, /You must provide both a key type and key data./
-      end
-    end
-
-    context 'with ssh public key missing key data' do
-      let :params do
-        {
-          :nova_public_key => {'type' => 'ssh-rsa'}
-        }
-      end
-
-      it 'should raise an error' do
-        expect {
-          is_expected.to contain_ssh_authorized_key('nova-migration-public-key').with(
-            :ensure => 'present',
-            :key => 'keydata'
-          )
-        }.to raise_error Puppet::Error, /You must provide both a key type and key data./
-      end
-    end
-
     {
       'ssh-rsa'     => 'id_rsa',
       'ssh-dsa'     => 'id_dsa',
@@ -366,55 +311,6 @@ describe 'nova' do
       end
     end
 
-    context 'with ssh private key missing key type' do
-      let :params do
-        {
-          :nova_private_key => {'key'  => 'keydata'}
-        }
-      end
-
-      it 'should raise an error' do
-        expect {
-          is_expected.to contain_file('/var/lib/nova/.ssh/id_rsa').with(
-            :content => 'keydata',
-          )
-        }.to raise_error Puppet::Error, /You must provide both a key type and key data./
-      end
-    end
-
-    context 'with ssh private key having incorrect key type' do
-      let :params do
-        {
-          :nova_private_key => {'type' => 'invalid',
-                                'key'  => 'keydata'}
-        }
-      end
-
-      it 'should raise an error' do
-        expect {
-          is_expected.to contain_file('/var/lib/nova/.ssh/id_rsa').with(
-            :content => 'keydata'
-          )
-        }.to raise_error Puppet::Error, /Unable to determine name of private key file./
-      end
-    end
-
-    context 'with ssh private key missing key data' do
-      let :params do
-        {
-          :nova_private_key => {'type' => 'ssh-rsa'}
-        }
-      end
-
-      it 'should raise an error' do
-        expect {
-          is_expected.to contain_file('/var/lib/nova/.ssh/id_rsa').with(
-            :content => 'keydata'
-          )
-        }.to raise_error Puppet::Error, /You must provide both a key type and key data./
-      end
-    end
-
     context 'with SSL socket options set' do
       let :params do
         {
