@@ -17,13 +17,15 @@ describe 'nova::keystone::auth' do
         :configure_endpoint  => true,
         :service_name        => 'nova',
         :service_type        => 'compute',
-        :service_description => 'Openstack Compute Service',
+        :service_description => 'OpenStack Compute Service',
         :region              => 'RegionOne',
         :auth_name           => 'nova',
         :password            => 'nova_password',
         :email               => 'nova@localhost',
         :tenant              => 'services',
         :roles               => ['admin'],
+        :system_scope        => 'all',
+        :system_roles        => [],
         :public_url          => 'http://127.0.0.1:8774/v2.1',
         :internal_url        => 'http://127.0.0.1:8774/v2.1',
         :admin_url           => 'http://127.0.0.1:8774/v2.1',
@@ -39,11 +41,13 @@ describe 'nova::keystone::auth' do
           :configure_endpoint  => false,
           :configure_user      => false,
           :configure_user_role => false,
-          :service_description => 'Alternative Openstack Compute Service',
+          :service_description => 'Alternative OpenStack Compute Service',
           :service_name        => 'alt_service',
           :service_type        => 'alt_compute',
           :region              => 'RegionTwo',
           :roles               => ['admin', 'service'],
+          :system_scope        => 'alt_all',
+          :system_roles        => ['admin', 'member', 'reader'],
           :public_url          => 'https://10.10.10.10:80',
           :internal_url        => 'http://10.10.10.11:81',
           :admin_url           => 'http://10.10.10.12:81' }
@@ -55,13 +59,15 @@ describe 'nova::keystone::auth' do
         :configure_endpoint  => false,
         :service_name        => 'alt_service',
         :service_type        => 'alt_compute',
-        :service_description => 'Alternative Openstack Compute Service',
+        :service_description => 'Alternative OpenStack Compute Service',
         :region              => 'RegionTwo',
         :auth_name           => 'alt_nova',
         :password            => 'nova_password',
         :email               => 'alt_nova@alt_localhost',
         :tenant              => 'alt_service',
         :roles               => ['admin', 'service'],
+        :system_scope        => 'alt_all',
+        :system_roles        => ['admin', 'member', 'reader'],
         :public_url          => 'https://10.10.10.10:80',
         :internal_url        => 'http://10.10.10.11:81',
         :admin_url           => 'http://10.10.10.12:81',
