@@ -17,7 +17,7 @@ describe 'nova::wsgi::apache_metadata' do
         :group                       => 'nova',
         :path                        => '/',
         :priority                    => 10,
-        :servername                  => facts[:fqdn],
+        :servername                  => 'foo.example.com',
         :ssl                         => false,
         :threads                     => 1,
         :user                        => 'nova',
@@ -53,7 +53,7 @@ describe 'nova::wsgi::apache_metadata' do
         {
           :servername                  => 'dummy.host',
           :bind_host                   => '10.42.51.1',
-          :api_port                    => 12345,
+          :port                        => 12345,
           :ssl                         => true,
           :vhost_custom_fragment       => 'Timeout 99',
           :wsgi_process_display_name   => 'nova-metadata',
@@ -212,14 +212,12 @@ describe 'nova::wsgi::apache_metadata' do
     context "on #{os}" do
       let (:facts) do
         facts.merge!(OSDefaults.get_facts({
-          :os_workers     => 42,
-          :concat_basedir => '/var/lib/puppet/concat',
-          :fqdn           => 'some.host.tld',
+          :os_workers => 42,
         }))
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           {
             :wsgi_script_path            => '/usr/lib/cgi-bin/nova',
